@@ -1,11 +1,12 @@
 package ExtUtils::MM_OS2;
 
 use strict;
+use warnings;
 
 use ExtUtils::MakeMaker qw(neatvalue);
 use File::Spec;
 
-our $VERSION = '7.36';
+our $VERSION = '7.64';
 $VERSION =~ tr/_//d;
 
 require ExtUtils::MM_Any;
@@ -24,7 +25,7 @@ ExtUtils::MM_OS2 - methods to override UN*X behaviour in ExtUtils::MakeMaker
 
 =head1 DESCRIPTION
 
-See ExtUtils::MM_Unix for a documentation of the methods provided
+See L<ExtUtils::MM_Unix> for a documentation of the methods provided
 there. This package overrides the implementation of these methods, not
 the semantics.
 
