@@ -11,7 +11,7 @@ use File::GlobMapper;
 require Exporter;
 our ($VERSION, @ISA, @EXPORT, %EXPORT_TAGS, $HAS_ENCODE);
 @ISA = qw(Exporter);
-$VERSION = '2.096';
+$VERSION = '2.106';
 
 @EXPORT = qw( isaFilehandle isaFilename isaScalar
               whatIsInput whatIsOutput
@@ -160,7 +160,7 @@ sub whatIsInput($;$)
         #use IO::File;
         $got = 'handle';
         $_[0] = *STDIN;
-        #$_[0] = new IO::File("<-");
+        #$_[0] = IO::File->new("<-");
     }
 
     return $got;
@@ -174,7 +174,7 @@ sub whatIsOutput($;$)
     {
         $got = 'handle';
         $_[0] = *STDOUT;
-        #$_[0] = new IO::File(">-");
+        #$_[0] = IO::File->new(">-");
     }
 
     return $got;
@@ -267,7 +267,7 @@ sub IO::Compress::Base::Validator::new
     {
         $data{GlobMap} = 1 ;
         $data{inType} = $data{outType} = 'filename';
-        my $mapper = new File::GlobMapper($_[0], $_[1]);
+        my $mapper = File::GlobMapper->new($_[0], $_[1]);
         if ( ! $mapper )
         {
             return $obj->saveErrorString($File::GlobMapper::Error) ;
@@ -509,7 +509,7 @@ sub ParseParameters
     return $_[1]
         if @_ == 2 && defined $_[1] && UNIVERSAL::isa($_[1], "IO::Compress::Base::Parameters");
 
-    my $p = new IO::Compress::Base::Parameters() ;
+    my $p = IO::Compress::Base::Parameters->new();
     $p->parse(@_)
         or croak "$sub: $p->[IxError]" ;
 
