@@ -16,11 +16,11 @@ TAP::Parser::SourceHandler::File - Stream TAP from a text file.
 
 =head1 VERSION
 
-Version 3.39
+Version 3.44
 
 =cut
 
-our $VERSION = '3.39';
+our $VERSION = '3.44';
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,8 @@ sub can_handle {
     return 0.9 if $file->{lc_ext} eq '.tap';
 
     if ( my $exts = $config->{extensions} ) {
-        return 0.9 if grep { lc($_) eq $file->{lc_ext} } @$exts;
+        my @exts = ref $exts eq 'ARRAY' ? @$exts : $exts;
+        return 0.9 if grep { lc($_) eq $file->{lc_ext} } @exts;
     }
 
     return 0;
